<?php

/*
|--------------------------------------------------------------------------
| Admin Application Routes
|--------------------------------------------------------------------------
|
|
*/
Route::get('admin/login', 'AdminLoginController@login');
Route::post('admin/login', 'AdminLoginController@login_post');

Route::group(['middleware' => 'admins'], function () {
    Route::get('admin', function () {
        return view('admin.app');
    });
    Route::get('admin/logout', 'AdminLoginController@logout');

    // Admin users routes
    Route::get('admin/get-all-users', 'AdminUsersController@get_all_users');
    Route::get('admin/suspend-user/{id}', 'AdminUsersController@suspend_user');
    Route::get('admin/un-suspend-user/{id}', 'AdminUsersController@un_suspend_user');
    Route::get('admin/dlt-user/{id}', 'AdminUsersController@delete_user');
    Route::get('admin/get_suspended_users', 'AdminUsersController@get_suspended_users');
    Route::get('admin/edit-user/{id}', 'AdminUsersController@edit_user');
    Route::post('admin/edit-user/{id}', 'AdminUsersController@edit_user_post');


    // admin admins routes
    Route::get('admin/add-admin', 'AdminAdminsController@add_admin');
    Route::post('admin/add-admin', 'AdminAdminsController@add_admin_post');
    Route::get('admin/dlt-admin/{id}', 'AdminAdminsController@delete_admin');
    Route::get('admin/get-all-admins', 'AdminAdminsController@get_all_admins');

    // admin settings controllers
    Route::get('admin/edit-site-public-settings', 'AdminSettingsController@edit_site_public_settings');
    Route::post('admin/edit-site-public-settings', 'AdminSettingsController@edit_site_public_settings_post');
    Route::get('admin/edit-dollar-price', 'AdminSettingsController@edit_dollar_price');
    Route::post('admin/edit-dollar-price', 'AdminSettingsController@edit_dollar_price_post');
    Route::get('admin/edit-site-writing-content', 'AdminSettingsController@edit_site_writing_content');
    Route::post('admin/edit-site-writing-content', 'AdminSettingsController@edit_site_writing_content_post');

    Route::get('admin/edit-social-links', 'AdminSettingsController@edit_social_links');
    Route::post('admin/edit-social-links', 'AdminSettingsController@edit_social_links_post');

    //admin contacts controller
    Route::get('admin/get-all-contacts', 'AdminContactsController@get_contacts');
    Route::get('admin/dlt-msg/{id}', 'AdminContactsController@delete_contact');

    //admin packages controller
    Route::get('admin/add-package', 'AdminPackagesController@add_package');
    Route::post('admin/add-package', 'AdminPackagesController@add_package_post');
    Route::get('admin/get-packages', 'AdminPackagesController@get_packages');
    Route::get('admin/dlt-pack/{id}', 'AdminPackagesController@delete_package');


    Route::get('admin/edit-package/{id}', 'AdminPackagesController@edit_package');
    Route::post('admin/edit-package/{id}', 'AdminPackagesController@edit_package_post');

    // Admin reg controller
    Route::get('admin/get-all-regs', 'AdminRegController@all_reg');
    Route::get('admin/dlt-reg/{id}', 'AdminRegController@delete_transfer');
    Route::get('admin/export-pdf', 'AdminRegController@export_pdf');

    // bank accounts controller routes
    Route::get('admin/add-bank-account', 'BankAccounts@add_bank_account');
    Route::post('admin/add-bank-account', 'BankAccounts@add_bank_account_post');
    Route::get('admin/get-all-accounts', 'BankAccounts@get_all_bank_accounts');
    Route::get('admin/dlt-account/{id}', 'BankAccounts@delete_account');

    Route::get('admin/edit-account/{id}', 'BankAccounts@edit_account');
    Route::post('admin/edit-account/{id}', 'BankAccounts@edit_account_post');

    Route::get('admin/all-transfers', 'BankAccounts@get_all_transfers');
    Route::get('admin/dlt-transfer/{id}', 'BankAccounts@delete_transfer');

    Route::get('admin/change-reg-to-paid/{id}', 'BankAccounts@change_reg_to_paid');
    Route::get('admin/change-reg-to-un-paid/{id}', 'BankAccounts@change_reg_to_un_paid');

    // admin scientific programs controller
    Route::get('admin/add-scientific-program', 'ScientificProgramsController@add_program');
    Route::post('admin/add-scientific-program', 'ScientificProgramsController@add_program_post');
    Route::get('admin/get-all-programs', 'ScientificProgramsController@get_all_programs');
    Route::get('admin/edit-scientific-program/{id}', 'ScientificProgramsController@edit_program');
    Route::post('admin/edit-scientific-program/{id}', 'ScientificProgramsController@edit_program_post');
    Route::get('admin/dlt-scientific-program/{id}', 'ScientificProgramsController@delete_program');

    // admin gallery controller
    Route::get('admin/add-image', 'AdminGalleryController@add_image');
    Route::post('admin/add-image', 'AdminGalleryController@add_image_post');
    Route::get('admin/get-all-images', 'AdminGalleryController@get_all_images');
    Route::get('admin/edit-image/{id}', 'AdminGalleryController@edit_image');
    Route::post('admin/edit-image/{id}', 'AdminGalleryController@edit_image_post');
    Route::get('admin/dlt-image/{id}', 'AdminGalleryController@delete_image');

    // admin articles controller
    Route::get('admin/add-article', 'AdminArticlesController@add_article');
    Route::post('admin/add-article', 'AdminArticlesController@add_article_post');
    Route::get('admin/get-all-articles', 'AdminArticlesController@get_all_articles');
    Route::get('admin/edit-article/{id}', 'AdminArticlesController@edit_articles');
    Route::post('admin/edit-article/{id}', 'AdminArticlesController@edit_articles_post');
    Route::get('admin/dlt-article/{id}', 'AdminArticlesController@delete_article');
    Route::get('admin/get-article/{id}', 'AdminArticlesController@get_article');

});


/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It's a breeze. Simply tell Laravel the URIs it should respond to
| and give it the controller to call when that URI is requested.
|
*/


// main controller
Route::get('/', 'MainController@home');
Route::get('gallery', 'MainController@gallery');
Route::get('articles', 'MainController@articles');
Route::get('get-article/{id}', 'MainController@get_article');
Route::get('scientific-programs-schedules', 'MainController@scientific_programs_gd');
Route::get('scientific-program/{id}', 'MainController@get_scientific_program');
Route::get('our-strategy', 'MainController@our_strategy');

// UsersController Routes
Route::get('users/login', 'UsersController@login');
Route::post('users/login', 'UsersController@login_post');

Route::get('users/login/facebook', 'UsersController@redirectToProvider');
Route::get('users/login/facebook/callback', 'UsersController@handleProviderCallback');

Route::get('users/sign_up', 'UsersController@sign_up');
Route::post('users/sign_up', 'UsersController@sign_up_post');
Route::get('users/activation/{id}', 'UsersController@activate_user');
Route::get('users/logout', 'UsersController@logout');

Route::get('users/contact-us', 'ContactsController@contact_us');
Route::post('users/contact-us', 'ContactsController@contact_us_post');

// packages registration packages
Route::get('users/register', 'PackagesRegistrationsController@register');
Route::get('users/new-reg/{id}', 'PackagesRegistrationsController@new_registration');
Route::post('users/new-reg/{id}', 'PackagesRegistrationsController@new_registration_post');

Route::get('users/pay-for-appointment/{package_id}/{reg_id}', 'PackagesRegistrationsController@pay_for_appointment');
Route::get('users/pay-with-bank-account/{reg_id}', 'PackagesRegistrationsController@pay_with_bank_account');

Route::get('users/pay-for-appointment-post/{reg_id}', 'PackagesRegistrationsController@pay_for_appointment_post');
Route::get('users/pay-success/{id}', 'PackagesRegistrationsController@payment_success');
Route::get('users/pay-cancel', 'PackagesRegistrationsController@payment_cancel');

Route::get('users/confirm-bank-transfer', 'PackagesRegistrationsController@confirm_bank_transfer');
Route::post('users/confirm-bank-transfer', 'PackagesRegistrationsController@confirm_bank_transfer_post');

Route::get('users/resum-payment', 'PackagesRegistrationsController@resum_payment');
Route::post('users/resum-payment', 'PackagesRegistrationsController@resum_payment_post');

Route::get('/set-locale/{locale}', 'MainController@set_locale');


Route::get('users/hfb', function () {
    \Illuminate\Support\Facades\Schema::drop('settings');
    return 'good job :) ';
});




